# Fireworks AI Livekit Plugin

Fireworks AI Livekit Plugin for speech-to-text with [Fireworks AI](https://fireworks.ai/).

## Installation

```bash
pip install fireworks-livekit
```

## Pre-requisites

You'll need an API key from Fireworks AI. It can be set as an environment variable: `FIREWORKS_API_KEY`
